CodeGenerator class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addElement(
ExtractedInfoModel element) → void - This function is responsible to get the specific element that we need to process and pull it from everywhere in the codebase to here to add and keep in the lists
-
generate(
LibraryReader library, BuildStep buildStep) → FutureOr< String?> - Generates Dart code for an input Dart library.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
componentsList
↔ Set<
ExtractedInfoModel> -
getter/setter pair
-
controllersList
↔ Set<
ExtractedInfoModel> -
getter/setter pair
-
importsList
↔ Set<
String> -
List Variables to keep the data and then we will use them when generating the code
This way everything, especially generating the code do so much faster and more efficient
getter/setter pair
-
pagesList
↔ Set<
ExtractedInfoModel> -
Lists to be filled and use to generate code
Pages and Dependencies
getter/setter pair
-
repositoriesList
↔ Set<
ExtractedInfoModel> -
getter/setter pair
-
servicesList
↔ Set<
ExtractedInfoModel> -
getter/setter pair