Strings class

Constructors

Strings()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

annotationArgumentAs String
no setter
annotationArgumentFenix String
no setter
annotationArgumentIsInitial String
Annotation Arguments
no setter
annotationArgumentIsUnknown String
no setter
annotationArgumentLazy String
no setter
empty String
no setter
space String
no setter
unknown String
no setter